/* riemann/riemann-client.h.in -- Riemann C client library
 * SPDX-FileCopyrightText: 2013-2024 Gergely Nagy
 * SPDX-FileContributor: Gergely Nagy
 *
 * SPDX-License-Identifier: EUPL-1.2
 */

#pragma once

#include <errno.h>

#include <riemann/attribute.h>
#include <riemann/event.h>
#include <riemann/query.h>
#include <riemann/message.h>
#include <riemann/client.h>
#include <riemann/communicate.h>

#define RCC_MAJOR_VERSION 2
#define RCC_MINOR_VERSION 2
#define RCC_PATCH_VERSION 0

#define RCC_VERSION_NUMBER 0x020200
